@@ -7,11 +7,24 @@ RDFLIB_VERSION = LooseVersion(rdflib.__version__)
 RDFLIB_421 = LooseVersion("4.2.1")
 RDFLIB_500 = LooseVersion("5.0.0")
 
+
 def rdflib_bool_patch():
     from rdflib.term import _toPythonMapping, _XSD_PFX, URIRef
     rdflib.NORMALIZE_LITERALS = False
-    _toPythonMapping[URIRef(_XSD_PFX + 'boolean')] = \
-        lambda i: i.lower() == 'true'
+    # we want to consider only 'true' to be a valid XSD:boolean truth (ie, ignore '1')
+    _toPythonMapping[URIRef(_XSD_PFX + 'boolean')] = lambda i: i.lower() == 'true'
+
+
+def rdflib_bool_unpatch():
+    from rdflib.term import _toPythonMapping, _XSD_PFX, URIRef
+    rdflib.NORMALIZE_LITERALS = True
+    if RDFLIB_500 > RDFLIB_VERSION:
+        # versions before rdflib 5.0.0
+        _toPythonMapping[URIRef(_XSD_PFX + 'boolean')] = lambda i: i.lower() in ['true', '1']
+    else:
+        # rdflib 5.0.0 and above
+        from rdflib.term import _parseBoolean
+        _toPythonMapping[URIRef(_XSD_PFX + 'boolean')] = _parseBoolean
 
 def rdflib_term_ge_le_patch():
     def __le__(term, other):
@@ -32,14 +45,7 @@ def rdflib_term_ge_le_patch():
     setattr(rdflib.term.Literal, "__le__", __le__)
 
 def apply_patches():
-    #applied = apply_patches.applied
-    #if applied:
-    #    return True
-    if RDFLIB_500 > RDFLIB_VERSION:
-        rdflib_bool_patch()
     if RDFLIB_421 >= RDFLIB_VERSION:
         rdflib_term_ge_le_patch()
-    #apply_patches.applied = True
     return True
-apply_patches.applied = False
 
